package com.huertian.jinduguanli.common;

/**
 * 
 *
 * @param <T>
 */
public class ApiResponse<T> {
    private int code;
    private String message;
    private T data;

    public ApiResponse() {
    }

    public ApiResponse(int code, String message, T data) {
        this.code = code;
        this.message = message;
        this.data = data;
    }

    public static <T> ApiResponse<T> success() {
        return new ApiResponse<>(10000, "成功", null);
    }

    public static <T> ApiResponse<T> success(T data) {
        return new ApiResponse<>(10000, "成功", data);
    }

    public static <T> ApiResponse<T> error(int code) {
        return new ApiResponse<>(code, getMessageByCode(code), null);
    }

    public static <T> ApiResponse<T> error(int code, String message) {
        return new ApiResponse<>(code, message, null);
    }

    private static String getMessageByCode(int code) {
        switch (code) {
            case 10001:
                return "参数无效";
            case 10002:
                return "邮箱已存在";
            case 10003:
                return "用户不存在";
            case 10004:
                return "密码错误";
            case 10005:
                return "用户已禁用";
            case 10006:
                return "未授权";
            case 10007:
                return "令牌已过期";
            case 10008:
                return "无效的令牌";
            case 10009:
                return "系统错误";
            default:
                return "未知错误";
        }
    }

    public int getCode() {
        return code;
    }

    public void setCode(int code) {
        this.code = code;
    }

    public String getMessage() {
        return message;
    }

    public void setMessage(String message) {
        this.message = message;
    }

    public T getData() {
        return data;
    }

    public void setData(T data) {
        this.data = data;
    }

    @Override
    public String toString() {
        return "ApiResponse{" +
                "code=" + code +
                ", message='" + message + '\'' +
                ", data=" + data +
                '}';
    }
}
