package com.huertian.jinduguanli.entity;

import jakarta.persistence.*;
import lombok.Data;
import lombok.ToString;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import java.io.Serializable;

@Entity
@Table(name = "lesson_tasks")
@Data
@ToString
public class LessonTask implements Serializable {
    private static final long serialVersionUID = 1L;

    private static final Logger logger = LoggerFactory.getLogger(LessonTask.class);

    @Id
    @GeneratedValue(strategy = GenerationType.IDENTITY)
    private Long id;

    @Column(nullable = false)
    private String courseName;

    @Column(nullable = false)
    private String microLessonName;

    @Column(nullable = false)
    private Long userId;

    @Column(nullable = false)
    private Integer progressStatus;

    private Long scriptCreateTime;
    private Long scriptReviewTime;
    private Long scriptConfirmTime;
    private Long videoCreateTime;
    private Long videoConfirmTime;
    private Long finishTime;
    
    private String advise;

    @Column(nullable = false)
    private Long createdAt;

    @Column(nullable = false)
    private Long updatedAt;

    @PrePersist
    protected void onCreate() {
        logger.info("创建新课程任务 - 课程名称: {}, 微课名称: {}, 用户ID: {}", 
            this.courseName, this.microLessonName, this.userId);
        progressStatus = 0; 
        long now = System.currentTimeMillis() / 1000;
        createdAt = now;
        updatedAt = now;
        logger.info("创建课程任务成功 - 进度状态: {}, 创建时间: {}, 更新时间: {}", 
            progressStatus, createdAt, updatedAt);
    }

    @PreUpdate
    protected void onUpdate() {
        logger.info("更新课程任务 - ID: {}, 课程名称: {}, 微课名称: {}", 
            this.id, this.courseName, this.microLessonName);
        updatedAt = System.currentTimeMillis() / 1000;
        logger.info("更新课程任务成功 - ID: {}, 更新时间: {}", id, updatedAt);
    }
}
