package com.huertian.jinduguanli.repository;

import com.huertian.jinduguanli.entity.LessonTask;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.Pageable;
import org.springframework.data.jpa.repository.JpaRepository;
import org.springframework.data.jpa.repository.Query;
import org.springframework.data.repository.query.Param;
import org.springframework.stereotype.Repository;

import java.util.List;
import java.util.Map;

@Repository
public interface LessonTaskRepository extends JpaRepository<LessonTask, Long> {
    Page<LessonTask> findByUserId(Long userId, Pageable pageable);

    /**
     * 查询指定部门的所有课程任务
     * 通过连接users表查询属于指定部门的所有用户的课程任务
     */
    @Query("SELECT lt FROM LessonTask lt JOIN User u ON lt.userId = u.id WHERE u.departmentId = :departmentId")
    List<LessonTask> findByDepartmentId(@Param("departmentId") Long departmentId);

    /**
     * 分页查询指定部门的所有课程任务
     */
    @Query("SELECT lt FROM LessonTask lt JOIN User u ON lt.userId = u.id WHERE u.departmentId = :departmentId")
    Page<LessonTask> findByDepartmentId(@Param("departmentId") Long departmentId, Pageable pageable);

    /**
     * 按部门ID和状态查询课程任务（分页）
     */
    @Query("SELECT lt FROM LessonTask lt JOIN User u ON lt.userId = u.id WHERE u.departmentId = :departmentId AND (:status IS NULL OR lt.progressStatus = :status)")
    Page<LessonTask> findByDepartmentIdAndStatus(
            @Param("departmentId") Long departmentId,
            @Param("status") Integer status,
            Pageable pageable);

    /**
     * 按部门ID和用户状态查询课程任务（分页）
     */
    @Query("SELECT lt FROM LessonTask lt JOIN User u ON lt.userId = u.id WHERE u.departmentId = :departmentId AND (:userStatus IS NULL OR u.status = :userStatus)")
    Page<LessonTask> findByDepartmentIdAndUserStatus(
            @Param("departmentId") Long departmentId,
            @Param("userStatus") Integer userStatus,
            Pageable pageable);

    /**
     * 按部门ID查询正常状态用户的课程任务（分页）
     */
    @Query("SELECT lt FROM LessonTask lt JOIN User u ON lt.userId = u.id WHERE u.departmentId = :departmentId AND u.status = 1")
    Page<LessonTask> findByDepartmentIdAndNormalUser(
            @Param("departmentId") Long departmentId,
            Pageable pageable);

    /**
     * 按部门ID查询正常状态用户的课程任务（分页），包含用户名
     */
    @Query("SELECT new map(lt as lessonTask, u.username as username) FROM LessonTask lt JOIN User u ON lt.userId = u.id WHERE u.departmentId = :departmentId AND u.status = 1")
    Page<Map<String, Object>> findByDepartmentIdAndNormalUserWithUsername(
            @Param("departmentId") Long departmentId,
            Pageable pageable);
}
