package com.huertian.jinduguanli.security.service;

import com.huertian.jinduguanli.entity.User;
import com.huertian.jinduguanli.repository.UserRepository;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.security.core.userdetails.UserDetails;
import org.springframework.security.core.userdetails.UsernameNotFoundException;
import org.springframework.stereotype.Service;

@Service
public class UserDetailsService implements org.springframework.security.core.userdetails.UserDetailsService {
    private final Logger logger = LoggerFactory.getLogger(UserDetailsService.class);
    private final UserRepository userRepository;

    public UserDetailsService(UserRepository userRepository) {
        this.userRepository = userRepository;
    }

    @Override
    public UserDetails loadUserByUsername(String email) throws UsernameNotFoundException {
        logger.info("开始加载用户信息 - 邮箱: {}", email);
        
        User user = userRepository.findByEmail(email)
                .orElseThrow(() -> {
                    logger.error("未找到用户 - 邮箱: {}", email);
                    return new UsernameNotFoundException("未找到用户");
                });

        logger.info("成功加载用户信息 - 用户名: {}", user.getUsername());
        return user;
    }
}
